==> ducene-0.0.2.tar.gz: test/query_test.dart <==
// Copyright (c) 2016, Shinichiro Abe. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

import 'package:ducene/ducene.dart';
import 'package:test/test.dart';

void main() {
  group('A group of query', () {
    Analyzer kwAnalyzer = new KeywordAnalyzer();

    test('test bool op', () {
      IndexDirectory indexDirectory = new RAMIndexDirectory();
      IndexWriter writer = new IndexWriter(indexDirectory);

      Document doc1 = new Document();
      doc1.append("id", 'xx', kwAnalyzer);
      Document doc2 = new Document();
      doc2.append("id", 'yy', kwAnalyzer);

      writer.write([doc1, doc2]);

      IndexReader reader = DirectoryReader.open(indexDirectory);
      IndexSearcher searcher = new IndexSearcher(reader);

      BoolQuery q = new BoolQuery(Op.or)
          .append('id', 'xx', kwAnalyzer)
          .append('id', 'yy', kwAnalyzer);
      expect(searcher.count(q), 2);

                q = new BoolQuery(Op.or)
          .append('id', 'xx', kwAnalyzer)
          .append('id', 'aa', kwAnalyzer);
      expect(searcher.count(q), 1);

                q = new BoolQuery(Op.and)
          .append('id', 'xx', kwAnalyzer)
          .append('id', 'yy', kwAnalyzer);
      expect(searcher.count(q), 0);

                q = new BoolQuery(Op.and)
          .append('id', 'xx', kwAnalyzer)
          .append('id', 'aa', kwAnalyzer);
      expect(searcher.count(q), 0);

                q = new BoolQuery(Op.or)
          .append('id', 'yy', kwAnalyzer);
      expect(searcher.count(q), 1);

                q = new BoolQuery(Op.and)
          .append('id', 'yy', kwAnalyzer);
      expect(searcher.count(q), 1);
    });

  });
}

==> ducene-0.1.0.tar.gz: test/query_test.dart <==
// Copyright (c) 2016, Shinichiro Abe. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

import 'package:ducene/ducene.dart';
import 'package:test/test.dart';

void main() {
  group('A group of query', () {

    test('test bool op', () {
      IndexDirectory indexDirectory = new RAMIndexDirectory();
      IndexWriter writer = new IndexWriter(indexDirectory);

      Document doc1 = new Document();
      doc1.append("id", 'xx');
      Document doc2 = new Document();
      doc2.append("id", 'yy');

      writer.write([doc1, doc2]);

      IndexReader reader = DirectoryReader.open(indexDirectory);
      IndexSearcher searcher = new IndexSearcher(reader);

      BoolQuery q = new BoolQuery(Op.or)
          .append('id', 'xx')
          .append('id', 'yy');
      expect(searcher.count(q), 2);

                q = new BoolQuery(Op.or)
          .append('id', 'xx')
          .append('id', 'aa');
      expect(searcher.count(q), 1);

                q = new BoolQuery(Op.and)
          .append('id', 'xx')
          .append('id', 'yy');
      expect(searcher.count(q), 0);

                q = new BoolQuery(Op.and)
          .append('id', 'xx')
          .append('id', 'aa');
      expect(searcher.count(q), 0);

                q = new BoolQuery(Op.or)
          .append('id', 'yy');
      expect(searcher.count(q), 1);

                q = new BoolQuery(Op.and)
          .append('id', 'yy');
      expect(searcher.count(q), 1);
    });

  });
}
